########################################################################
#第6章
# Working directoryが 'toyoda' であることの確認
(n_wd<-getwd())                        #working directoryの確認
(setwd('./scrJ'))
source('../myfunc/myfunc.R')      #自作関数の読み込み
(setwd(n_wd))
   library(cmdstanr)              #パッケージcmdstanrの呼び出し
   library(posterior)             #パッケージposteriorの呼び出し

#表6.1 実験群と対照群の英語の成績
#実験群
x1<-c(49,66,69,55,54,72,51,76,40,62,66,51,59,68,66,57,53,66,58,57)
#対照群
x2<-c(41,55,21,49,53,50,52,67,54,69,57,48,31,52,56,50,46,38,62,59)
print(x1);print(x2)

#表6.2 「英語データ」の数値要約　
(n1<-length(x1));(n2<-length(x2))         #データの数
mean(x1);mean(x2)                         #平均値
van<-function(x){mean((x-mean(x))^2)}     #分散を計算する関数
van(x1);van(x2)                           #分散
sqrt(van(x1));sqrt(van(x2))               #標準偏差
sort(x1);sort(x2)                         #小さい順に並べる
median(x1);median(x2)                     #中央値
quantile(x1,type =2);quantile(x2,type =2) #％点

#表6.3 小さい順に並べ替えた測定値
sort(x1);sort(x2)

#図6.1 「英語データ」の箱ひげ図
x<-c(x1,x2);y<-c(rep("実験群",n1),rep("対照群",n2))
boxplot(x~y,cex.axis=2.0,xlab="",ylab="")                 
#dev.copy2eps(file="z03boxplot.eps",family="Japan1")


#G2Indは、独立した2群の差の推測、
# x1: ベクトル形式の第1群のデータ (平均値の大きな群)
# x2: ベクトル形式の第2群のデータ (平均値の小さな群)
# EQU: 論理値。1なら等分散。0なら異なる分散。
# prior: 論理値。Tなら事前分布の範囲を指定。Fなら指定せず(stanのデフォルト)。
# mL, mH, sL, sH: 事前分布の母数/一様分布の平均下限・上限/標準偏差下限・上限
out0601<-G2Ind(x1,x2,EQU=0,prior=F)

#save(out0601,  file="./scrJ/obje/out0601")
#load(file="./scrJ/obje/out0601"); #予めMCMCした結果をロード

#表6.4 母数の事後分布の数値要約
gqcal(out0601$ext[,1:6])

#MCMC標本の名前が長いので取り出す。
mu1   <-out0601$mu1;      mu2<-out0601$mu2;
sigma1<-out0601$sigma1;sigma2<-out0601$sigma2;
xaste1<-out0601$xaste1;xaste2<-out0601$xaste2;


#図6.2 実験群と対照群の事後分布の比較
#mu1,mu2・sigma1,sigma2の事後分布の位置関係の確認
par(mfrow=c(1,2))
#左図
plot(density(mu1),xlim=c(40,70),ylim=c(0,0.2),cex.axis=2.0,
      cex.lab=2.0,main="",xlab="",ylab="",lwd=2.0)
      text(66.0,0.15,"実験群",cex=2.0)
par(new=T)
plot(density(mu2),xlim=c(40,70),ylim=c(0,0.2),cex.axis=2.0,
      cex.lab=2.0,main="",xlab="平均",ylab="",lwd=2.0)
      text(44.5,0.15,"対照群",cex=2.0)
#右図
plot(density(sigma1),xlim=c(5,25),ylim=c(0,0.28)
,cex.axis=2.0,cex.lab=2.0,main="",xlab="",ylab="",lwd=2.0)  
text( 6.5,0.25,"実験群",cex=2.0)
par(new=T)
plot(density(sigma2),,xlim=c(5,25),ylim=c(0,0.28)
,cex.axis=2.0,cex.lab=2.0,main="",xlab="標準偏差",ylab="",lwd=2.0)  
text(16.0,0.17,"対照群",cex=2.0)
par(mfrow=c(1,1))
#dev.copy2eps(file="z0602qq.eps",family="Japan1")


#表6.5 生成量の事後分布の数値要約
dmu     <-mu1-mu2;       #平均の差
dsigma  <-sigma1-sigma2; #標準偏差の差
gqcal(cbind(dmu,dsigma),2)

#図6.3 生成量の事後分布の図的要約（平均の差・標準偏差の差の事後分布）
par(mfrow=c(1,2))
hist(dmu ,breaks=100,col=gray(1.0)
,cex.axis=2.0,cex.lab=2.0,main="",xlab="平均の差",ylab="") 
hist(dsigma ,breaks=100,col=gray(1.0)
,cex.axis=2.0,cex.lab=2.0,main="",xlab="標準偏差の差",ylab="") 
par(mfrow=c(1,1))
#dev.copy2eps(file="z0603qq.eps",family="Japan1")

#表6.6  差があるという仮説のphcテーブル
phc01(c(0,3,5,10,15,20),dmu,cc="gtc",byoga="no")
phc01(c(-20,-15,-10,-5,-3,0),dsigma,cc="ltc",byoga="no")

#図6.4  差があるという仮説のphc曲線
par(mfrow=c(2,1))
phc01(seq(0,20,1.0),dmu,cc="gtc",byoga="yes",xlab="平均の差")
phc01(seq(-20,5,1.0),dsigma,cc="ltc",byoga="yes",xlab="標準偏差の差")
par(mfrow=c(1,1))
#dev.copy2eps(file="z0604qq.eps",family="Japan1")

#表6.7  事実上差がないというROPEの仮説のphcテーブル
phc01(c(0,3,5,10,15,20),dmu,   cc="rope",byoga="no")
phc01(c(0,3,5,10,15,20),dsigma,cc="rope",byoga="no")

#図6.5  事実上差がないというROPEの仮説のphc曲線
par(mfrow=c(2,1))
phc01(seq(0,20,1.0),dmu,   cc="rope",byoga="yes",xlab="平均の差")
phc01(seq(0,20,1.0),dsigma,cc="rope",byoga="yes",xlab="標準偏差の差")
par(mfrow=c(1,1))
#dev.copy2eps(file="z0605qq.eps",family="Japan1")

#おまけ、伝統的なt検定、等分散・両側
t.test(x1,x2,var.equal = F)

########################################################################
#第6章 6.5 実習課題 p.87

#表6.8 聴音条件の知覚時間の測定結果(秒)
#聴音条件のデータ入力
y1<-c(32.30,34.24,28.10,33.40,37.71,31.62,31.37,35.85,32.33,34.04,
     34.96,31.43,35.28,30.19,35.09,33.38,31.49,28.44,32.12,31.81)

#対照条件のデータ入力
y2<-c(31.43,31.09,33.38,30.49,29.62,35.40,32.58,28.96,29.43,28.52,
     25.39,32.68,30.51,30.15,32.33,30.43,32.50,32.07,32.35,31.57)

out0602<-G2Ind(y1,y2,EQU=0,prior=F)
#save(out0602,  file="./scrJ/obje/out0602")
#load(file="./scrJ/obje/out0602"); #予めMCMCした結果をロード
gqcal(out0602$ext[,1:6])

#その他のスクリプト例は割愛する


########################################################################

#自習 副読本 p.26, p.92
#　新しく発売された抗菌薬A の肺炎に対する治療効果を調べるために，
#新たに入院する肺炎患者を対象として，抗菌薬A を投与した群(A 群) と
#既存の抗菌薬B を投与した群(B 群) とに割り付けて，
#治療効果を入院期間で比較検討した．
#1)平均値の差の事後分布の要約統計量を解釈せよ
#2)平均値の差のphc曲線を考察せよ。
#3)平均値の差のropeの曲線を考察せよ。
#4)平均値の差の有意性検定をして、解釈せよ。

#表6-1　抗菌薬Aの治療効果の生データ
実験群<-c(5.5,10.0,5.5,6.0,9.0,9.5,6.5,7.0,12.5,7.0,6.5,10.5,
                 9.0,4.5,6.5,9.5,10.0,9.5,10.5,6.5,8.5,12.5,4.0,9.0)
対照群<-c(5.5,11.5,7.0,7.5,10.5,11.0,8.0,8.5,14.0,8.5,10.0,8.0,12.0,
                 10.5,6.0,8.0,11.0,11.5,11.0,12.0,8.0,10.0,14.0,5.5,10.5,9.0)

#EAP推定値、確信区間
out0603<-G2Ind(対照群,実験群,EQU=0,prior=T,mL=0, mH=100, sL=0, sH=100)
#save(out0603,  file="./scrJ/obje/out0603")
#load(file="./scrJ/obje/out0603"); #予めMCMCした結果をロード

mean_def<-out0603$mu1-out0603$mu2;                         #母平均差の事後分布

#1)平均値の差の事後分布の要約統計量を解釈せよ
gqcal(mean_def)

#2)平均値の差のphc曲線を考察せよ。
phc01(seq(0.0,0.5,0.1),mean_def,0,cc="gtc", byoga="no");   #表6-2
phc01(seq(0.6,2.0,0.2),mean_def,0,cc="gtc", byoga="no")
phc01(seq(2.5,4.0,0.5),mean_def,0,cc="gtc", byoga="no")

#3)平均値の差のropeの曲線を考察せよ。
phc01(seq(0.0,1.0,0.1),mean_def,0,cc="rope", byoga="no");  #表6-3
phc01(seq(2.0,3.0,0.1),mean_def,0,cc="rope", byoga="no")

#4)平均値の差の有意性検定をして、解釈せよ。
t.test(対照群,実験群,paired=F,var.equal=F)


